import type { VxeGridProps } from '#/adapter/vxe-table';

import { DictEnum } from '@vben/constants';
import { getPopupContainer } from '@vben/utils';

import { type FormSchemaGetter } from '#/adapter/form';
import { getDictOptions } from '#/utils/dict';

export const querySchema: FormSchemaGetter = () => [
  {
    component: 'Input',
    fieldName: 'orderCode',
    label: '出库单号'
  },
  {
    component: 'TreeSelect',
    // 在drawer里更新 这里不需要默认的componentProps
    defaultValue: undefined,
    fieldName: 'chargeDept',
    label: '经办部门'
  },
  {
    component: 'Select',
    componentProps: {
      showSearch: true,
      allowClear: true,
      getPopupContainer
    },
    fieldName: 'chargeUser',
    label: '经办人'
  },
  {
    component: 'Input',
    fieldName: 'partnerName',
    label: '客户'
  },
  {
    component: 'RangePicker',
    fieldName: 'orderTime',
    label: '工单时间'
  }
];

export const columns: VxeGridProps['columns'] = [
  { type: 'checkbox', width: 60, fixed: 'left' },
  {
    title: '出库单号',
    field: 'orderCode',
    minWidth: 100,
    fixed: 'left',
    slots: { default: 'orderCode' }
  },
  {
    title: '日期',
    field: 'orderTime',
    minWidth: 120
  },
  {
    title: '客户',
    field: 'partnerName',
    minWidth: 100
  },
  {
    title: '经办人',
    field: 'chargeUserName',
    minWidth: 100
  },
  {
    title: '关联单号',
    field: 'associatedOrder',
    minWidth: 120
  },
  {
    title: '备注',
    field: 'remark',
    minWidth: 140
  },
  {
    field: 'action',
    fixed: 'right',
    slots: { default: 'action' },
    title: '操作',
    width: 200
  }
];

export const drawerSchema: FormSchemaGetter = () => [
  {
    component: 'Input',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    },
    fieldName: 'id'
  },
  {
    component: 'Select',
    componentProps: {
      getPopupContainer,
      options: getDictOptions(DictEnum.SPARE_INOUT_TYPE)
    },
    dependencies: {
      show: () => true,
      triggerFields: ['']
    },
    fieldName: 'type',
    defaultValue: '2',
    label: '类型'
  },
  {
    component: 'Input',
    fieldName: 'orderCode',
    label: '出库单号'
  },
  {
    component: 'Input',
    fieldName: 'partnerName',
    label: '客户'
  },
  {
    component: 'TreeSelect',
    // 在drawer里更新 这里不需要默认的componentProps
    defaultValue: undefined,
    fieldName: 'chargeDept',
    label: '经办部门',
    rules: 'selectRequired'
  },
  {
    component: 'Select',
    componentProps: {
      showSearch: true,
      allowClear: true,
      getPopupContainer
    },
    fieldName: 'chargeUser',
    label: '经办人',
    rules: 'required'
  },
  {
    component: 'DatePicker',
    componentProps: {
      format: 'YYYY-MM-DD HH:mm:ss',
      showTime: true,
      valueFormat: 'YYYY-MM-DD HH:mm:ss',
      getPopupContainer
    },
    fieldName: 'orderTime',
    label: '出库时间'
  },
  {
    component: 'Textarea',
    formItemClass: 'items-baseline',
    fieldName: 'remark',
    label: '备注'
  }
];
